@@ -57,7 +57,7 @@ void JournalDateView::clear()
 // should only be called by the JournalView now.
 void JournalDateView::addJournal(const Akonadi::Item &j)
 {
-    QMap<Akonadi::Item::Id, JournalFrame *>::Iterator pos = mEntries.find(j.id());
+    QMap<Akonadi::Item::Id, JournalFrame *>::Iterator pos = mEntries.find(j.id()); // NOLINT(misc-const-correctness)
     if (pos != mEntries.end()) {
         return;
     }
@@ -80,10 +80,7 @@ void JournalDateView::addJournal(const Akonadi::Item &j)
     connect(entry, &JournalFrame::deleteIncidence, this, &JournalDateView::deleteIncidence);
     connect(entry, &JournalFrame::editIncidence, this, &JournalDateView::editIncidence);
     connect(entry, &JournalFrame::incidenceSelected, this, &JournalDateView::incidenceSelected);
-    connect(entry,
-            qOverload<const KCalendarCore::Journal::Ptr &, bool>(&JournalFrame::printJournal),
-            this,
-            qOverload<const KCalendarCore::Journal::Ptr &, bool>(&JournalDateView::printJournal));
+    connect(entry, &JournalFrame::printJournalSignal, this, qOverload<const KCalendarCore::Journal::Ptr &, bool>(&JournalDateView::printJournal));
 }
 
 Akonadi::Item::List JournalDateView::journals() const
@@ -109,7 +106,7 @@ void JournalDateView::emitNewJournal()
 
 void JournalDateView::journalEdited(const Akonadi::Item &journal)
 {
-    QMap<Akonadi::Item::Id, JournalFrame *>::Iterator pos = mEntries.find(journal.id());
+    QMap<Akonadi::Item::Id, JournalFrame *>::Iterator pos = mEntries.find(journal.id()); // NOLINT(misc-const-correctness)
     if (pos == mEntries.end()) {
         return;
     }
@@ -119,7 +116,7 @@ void JournalDateView::journalEdited(const Akonadi::Item &journal)
 
 void JournalDateView::journalDeleted(const Akonadi::Item &journal)
 {
-    QMap<Akonadi::Item::Id, JournalFrame *>::Iterator pos = mEntries.find(journal.id());
+    QMap<Akonadi::Item::Id, JournalFrame *>::Iterator pos = mEntries.find(journal.id()); // NOLINT(misc-const-correctness)
     if (pos == mEntries.end()) {
         return;
     }
@@ -150,40 +147,41 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::CollectionCale
 
     mEditButton = new QPushButton(this);
     mEditButton->setObjectName("editButton"_L1);
-    mEditButton->setText(i18n("&Edit"));
+    mEditButton->setText(i18nc("@action: button", "&Edit"));
     mEditButton->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     mEditButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     mEditButton->setToolTip(i18nc("@info:tooltip", "Edit this journal entry"));
-    mEditButton->setWhatsThis(i18n("Opens an editor dialog for this journal entry"));
+    mEditButton->setWhatsThis(i18nc("@info:whatsthis", "Opens an editor dialog for this journal entry"));
     buttonsLayout->addWidget(mEditButton);
     connect(mEditButton, &QPushButton::clicked, this, &JournalFrame::editItem);
 
     mDeleteButton = new QPushButton(this);
     mDeleteButton->setObjectName("deleteButton"_L1);
-    mDeleteButton->setText(i18n("&Delete"));
+    mDeleteButton->setText(i18nc("@action: button", "&Delete"));
     mDeleteButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     mDeleteButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     mDeleteButton->setToolTip(i18nc("@info:tooltip", "Delete this journal entry"));
-    mDeleteButton->setWhatsThis(i18n("Delete this journal entry"));
+    mDeleteButton->setWhatsThis(i18nc("@info:whatsthis", "Delete this journal entry"));
     buttonsLayout->addWidget(mDeleteButton);
     connect(mDeleteButton, &QPushButton::pressed, this, &JournalFrame::deleteItem);
 
     mPrintButton = new QPushButton(this);
-    mPrintButton->setText(i18n("&Print"));
+    mPrintButton->setText(i18nc("@action: button", "&Print"));
     mPrintButton->setObjectName("printButton"_L1);
     mPrintButton->setIcon(QIcon::fromTheme(QStringLiteral("document-print")));
     mPrintButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     mPrintButton->setToolTip(i18nc("@info:tooltip", "Print this journal entry"));
-    mPrintButton->setWhatsThis(i18n("Opens a print dialog for this journal entry"));
+    mPrintButton->setWhatsThis(i18nc("@info:whatsthis", "Opens a print dialog for this journal entry"));
     buttonsLayout->addWidget(mPrintButton);
-    connect(mPrintButton, &QPushButton::clicked, this, qOverload<>(&JournalFrame::printJournal));
+    connect(mPrintButton, &QPushButton::clicked, this, &JournalFrame::printJournal);
 
     mPrintPreviewButton = new QPushButton(this);
-    mPrintPreviewButton->setText(i18n("Print preview"));
+    mPrintPreviewButton->setText(i18nc("@action: button", "Print preview"));
     mPrintPreviewButton->setObjectName("printButton"_L1);
     mPrintPreviewButton->setIcon(QIcon::fromTheme(QStringLiteral("document-print-preview")));
     mPrintPreviewButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     mPrintPreviewButton->setToolTip(i18nc("@info:tooltip", "Print preview this journal entry"));
+    mPrintPreviewButton->setWhatsThis(i18nc("@info:whatsthis", "Opens a print preview of this journal entry"));
     buttonsLayout->addWidget(mPrintPreviewButton);
     connect(mPrintPreviewButton, &QAbstractButton::clicked, this, &JournalFrame::printPreviewJournal);
 
@@ -264,19 +262,19 @@ void JournalFrame::setDirty()
 
 void JournalFrame::printJournal()
 {
-    Q_EMIT printJournal(Akonadi::CalendarUtils::journal(mJournal), false);
+    Q_EMIT printJournalSignal(Akonadi::CalendarUtils::journal(mJournal), false);
 }
 
 void JournalFrame::printPreviewJournal()
 {
-    Q_EMIT printJournal(Akonadi::CalendarUtils::journal(mJournal), true);
+    Q_EMIT printJournalSignal(Akonadi::CalendarUtils::journal(mJournal), true);
 }
 
-void JournalFrame::readJournal(const Akonadi::Item &j)
+void JournalFrame::readJournal(const Akonadi::Item &item)
 {
-    int baseFontSize = QFontDatabase::systemFont(QFontDatabase::GeneralFont).pointSize();
-    mJournal = j;
-    const KCalendarCore::Journal::Ptr journal = Akonadi::CalendarUtils::journal(j);
+    int const baseFontSize = QFontDatabase::systemFont(QFontDatabase::GeneralFont).pointSize();
+    mJournal = item;
+    const KCalendarCore::Journal::Ptr j = Akonadi::CalendarUtils::journal(item);
     mBrowser->clear();
     QTextCursor cursor = QTextCursor(mBrowser->textCursor());
     cursor.movePosition(QTextCursor::Start);
@@ -284,23 +282,23 @@ void JournalFrame::readJournal(const Akonadi::Item &j)
     QTextBlockFormat bodyBlock = QTextBlockFormat(cursor.blockFormat());
     // FIXME: Do padding
     bodyBlock.setTextIndent(2);
-    QTextCharFormat bodyFormat = QTextCharFormat(cursor.charFormat());
-    if (!journal->summary().isEmpty()) {
+    QTextCharFormat const bodyFormat = QTextCharFormat(cursor.charFormat());
+    if (!j->summary().isEmpty()) {
         QTextCharFormat titleFormat = bodyFormat;
         titleFormat.setFontWeight(QFont::Bold);
         titleFormat.setFontPointSize(baseFontSize + 4);
-        cursor.insertText(journal->summary(), titleFormat);
+        cursor.insertText(j->summary(), titleFormat);
         cursor.insertBlock();
     }
     QTextCharFormat dateFormat = bodyFormat;
     dateFormat.setFontWeight(QFont::Bold);
     dateFormat.setFontPointSize(baseFontSize + 1);
-    cursor.insertText(KCalUtils::IncidenceFormatter::dateTimeToString(journal->dtStart(), journal->allDay()), dateFormat);
+    cursor.insertText(KCalUtils::IncidenceFormatter::dateTimeToString(j->dtStart(), j->allDay()), dateFormat);
     cursor.insertBlock();
     cursor.insertBlock();
     cursor.setBlockCharFormat(bodyFormat);
-    const QString description = journal->description();
-    if (journal->descriptionIsRich()) {
+    const QString description = j->description();
+    if (j->descriptionIsRich()) {
         mBrowser->insertHtml(description);
     } else {
         mBrowser->insertPlainText(description);
